diff --git a/source/main.cpp b/source/main.cpp
index 8ba3929741f0dc3820dff72f140d7904085e7dd4..801e99e85b533e9d9da34c6ea97c09167867f461 100755
--- a/source/main.cpp
+++ b/source/main.cpp
@@ -331,7 +331,7 @@ void start_new_game() {
         MICROBIT_ID_BUTTON_B, MICROBIT_BUTTON_EVT_CLICK, b_button_pressed
     );
     unsigned long stopwatch = UBIT.systemTime();
-    unsigned long move_speed = 350; // move down one block every 350ms
+    unsigned long move_speed = 500; // move down one block every 500ms
     // this is the main game loop
     do {
         // XXX: for demo, keep sending random Blocks until stacked up to ceiling